//+------------------------------------------------------------------+
//|                                                                  |
//|                                                                  |
//+------------------------------------------------------------------+
#define MAGIC 0605000

//---- input parameters
extern int       RiskMax=7;
extern double    LotsMax=90.0;
extern int       DecreaseFactor=12;
extern int       TakeProfit=100;
extern int       StopLoss=40;
extern int       TrailingStop=10;

//+------------------------------------------------------------------+
//|                                     |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
//----
   double Lots=NormalizeDouble(AccountBalance()*RiskMax/100000.0,1);
   if(AccountFreeMargin()<(1000*Lots))
     {
      Lots=NormalizeDouble(AccountFreeMargin()*RiskMax/100000.0,1);
     }
   if(Lots>LotsMax)
     {
      Lots=LotsMax;
     }
   
   int orders=HistoryTotal();
   int losses=0;
   
   if(DecreaseFactor>0)
     {
      for(int i=orders-1;i>=0;i--)
        {
         if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==false)
           {
            Print("  !");
            break;
           }
         if(OrderSymbol()!=Symbol() || OrderMagicNumber()!=MAGIC || OrderType()>OP_SELL)continue;
         if(OrderProfit()>0) break;
         if(OrderProfit()<0) losses++;
        }
         if(losses>1)
           {
            Lots=NormalizeDouble(Lots/(DecreaseFactor*(losses+1)),1);
           }
       }
     if(Lots<0.1)
       {
        Lots=0.1;
       }       
//----
   return(Lots);
  }


bool symbolOrders()
   {
   int orders = OrdersTotal();
   for(int i=orders-1; i>=0; i--)
      {
      if(!OrderSelect(i, SELECT_BY_POS ))
         {
         Print("OrderSelect( ", i, ", SELECT_BY_POS ) - Error #", GetLastError());
         continue;
         }
         if(OrderSymbol()==Symbol())
            {
            if(OrderMagicNumber()==MAGIC)
               {
               return(true);
        }
          }
     }
    return(false);
}

//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
  {
//----
   int trade, cnt, ticket;
   int total=OrdersTotal();

   if(Bars<100)
     {
      Print("   100");
      return(0);  
     }
   if(TakeProfit<10)
     {
      TakeProfit=10;
      Print(" TakeProfit   10,    10");
     }

   if(!symbolOrders())
     {
      if(AccountFreeMargin()<(1000*LotsOptimized()))
        {
         Print("   .   = ", AccountFreeMargin());
         return(0);
        }
      int a,b;
      if(a>b)
        {
         if(!IsTradeAllowed())
           {
            Print("  .");
            return(0);
           }       
         ticket=OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,3,Ask-StopLoss*Point,Ask+TakeProfit*Point,"AD BUY",MAGIC,0,Green);
         if(ticket>0)
           {
            if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES))
              {
               Print("      AD BUY: ",OrderOpenPrice());
              }
            else
              {
               Print("       AD BUY: ",GetLastError());
               return(0);
              }
           }         
        }
                
      if(a<b)
        {
         if(!IsTradeAllowed())
           {
            Print("  .");
            return(0);
           }
         ticket=OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,3,Bid+StopLoss*Point,Bid-TakeProfit*Point,"AD SELL",MAGIC,0,Red);
         if(ticket>0)
           {
           if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES))
              {
               Print("      AD SELL: ",OrderOpenPrice());
              }
            else
              {
               Print("       AD SELL: ",GetLastError());
               return(0);
              }
           }
        }
     }
     
   for(cnt=0;cnt<total;cnt++)
     {
      OrderSelect(cnt,SELECT_BY_POS,MODE_TRADES);
      if(OrderType()<=OP_SELL && OrderSymbol()==Symbol() && OrderMagicNumber()==MAGIC)
        {
         if(OrderType()==OP_BUY)
           {
            if(a<b)
              {
               if(!IsTradeAllowed())
                 {
                  Print("  .");
                  return(0);
                 }       
               OrderClose(OrderTicket(),OrderLots(),Bid,3,Violet);
               return(0);
              }
            if(TrailingStop>0)
              {
               if(Bid-OrderOpenPrice()>Point*TrailingStop)
                 {
                  if(OrderStopLoss()<Bid-Point*TrailingStop)
                    {
                     if(!IsTradeAllowed())
                       {
                        Print("  .");
                        return(0);
                       }       
                     OrderModify(OrderTicket(),OrderOpenPrice(),Bid-Point*TrailingStop,OrderTakeProfit(),0,Green);
                     return(0);
                    }
                 }
              }
           }
         else
           {
            if(a>b)
              {
               if(!IsTradeAllowed())
                 {
                  Print("  .");
                  return(0);
                 }                    
               OrderClose(OrderTicket(),OrderLots(),Ask,3,Violet);
               return(0);
              }
            if(TrailingStop>0)
              {
               if((OrderOpenPrice()-Ask)>(Point*TrailingStop))
                 {
                  if((OrderStopLoss()>(Ask+Point*TrailingStop)) || (OrderStopLoss()==0))
                    {
                     if(!IsTradeAllowed())
                       {
                        Print("  .");
                        return(0);
                       }                   
                     OrderModify(OrderTicket(),OrderOpenPrice(),Ask+Point*TrailingStop,OrderTakeProfit(),0,Red);
                     return(0);
                    }
                 }
              }
           }
        }      
     }
//----
   return(0);
  }